@@ -20,8 +20,8 @@ class MUX(TCA9548):
 
     address = None
 
-    def __init__(self, *args):
-        super().__init__(*args)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         # A list of connected sensors
         self.sensors = []
 
